@@ -1,6 +1,6 @@
-from skylink.ext.db import create_db
-from skylink.ext.es import create_es
-from skylink.ext.eredis import create_redis
+from skyext.db import create_db
+from skyext.es import create_es
+from skyext.eredis import create_redis
 
 EXT_CONTEXT = {
 
